@@ -1,6 +1,10 @@
 from bs4 import BeautifulSoup
+from colorama import Fore
+from tldextract import tldextract
+from yarl import URL
 
-from ..data_classes import *
+from ..base_functions import bunkr_parse, log, logger, make_title_safe, ssl_context, check_direct
+from ..data_classes import DomainItem
 
 
 class ChibisafeCrawler():
@@ -12,6 +16,10 @@ class ChibisafeCrawler():
         base_domain = "{}.{}".format(url_extract.domain, url_extract.suffix)
         domain_obj = DomainItem(base_domain, {})
 
+        if check_direct(url):
+            await domain_obj.add_to_album(link=url, referral=url, title="Chibisafe Loose Files")
+            return domain_obj
+
         await log("Starting scrape of " + str(url), Fore.WHITE)
 
         try:
